# IcepapOSC

IcepapOSC is a python module and application to monitor and tune IcePAP based systems.

To install it on the system: 

    python setup.py install

To install locally:

    python setup.py install --prefix=<local_folder> --root=/
    
Note: You need to include on the PYTHONPATH the installation folder.

 
To lunch the application:

    icepaposc <host>


You can find how to contribute to this project on CONTRIBUTING.md file.
